@@ -1,7 +1,4 @@
-
-
-class DjSuperAdminMixin():
-
+class DjSuperAdminMixin:
     @property
     def superadmin_get_url(self):
         raise NotImplementedError("You must define superadmin_get_url!")
